@@ -3,7 +3,7 @@ package BorderStyleBase;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-01-31'; # DATE
 our $DIST = 'BorderStyleBase'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use strict 'subs', 'vars';
 #use warnings;
@@ -30,6 +30,10 @@ sub get_border_char {
     my $bs_struct = $self->get_struct;
 
     my $c = $bs_struct->{chars}[$y][$x];
+    if (!defined($c)) {
+        if    ($y == 6) { $c = $bs_struct->{chars}[0][$x] }
+        elsif ($y == 7) { $c = $bs_struct->{chars}[5][$x] }
+    }
     return unless defined $c;
 
     if (ref $c eq 'CODE') {
@@ -61,7 +65,7 @@ BorderStyleBase - A suitable base class for most BorderStyle::* modules
 
 =head1 VERSION
 
-This document describes version 0.006 of BorderStyleBase (from Perl distribution BorderStyleBase), released on 2021-01-31.
+This document describes version 0.007 of BorderStyleBase (from Perl distribution BorderStyleBase), released on 2021-01-31.
 
 =head1 DESCRIPTION
 
